@@ -9,9 +9,7 @@ from typing_extensions import override
 
 
 class BaseFile(ABC):
-    def __init__(
-        self, url: str | None = None, path: str | None = None
-    ) -> None:
+    def __init__(self, url: str | None = None, path: str | None = None) -> None:
         self.url = url
         self.path = path
 
@@ -47,9 +45,7 @@ class Photo(BaseFile):
         ".bmp",
     }  # FIXME: костыль ✅
 
-    def __init__(
-        self, url: str | None = None, path: str | None = None
-    ) -> None:
+    def __init__(self, url: str | None = None, path: str | None = None) -> None:
         super().__init__(url, path)
 
     def validate_photo(self) -> tuple[str, str] | None:
@@ -71,9 +67,7 @@ class Photo(BaseFile):
             mime_type = mimetypes.guess_type(self.url)[0]
 
             if not mime_type or not mime_type.startswith("image/"):
-                raise ValueError(
-                    f"URL does not appear to be an image: {self.url}"
-                )
+                raise ValueError(f"URL does not appear to be an image: {self.url}")
 
             return (extension[1:], mime_type)
         return None
@@ -84,15 +78,24 @@ class Photo(BaseFile):
 
 
 class Video(BaseFile):
+    def __init__(self, url: str | None = None, path: str | None = None) -> None:
+        self.file_name: str = ""
+        if path:
+            self.file_name = Path(path).name
+        elif url:
+            self.file_name = Path(url).name
+
+        if not self.file_name:
+            raise ValueError("Either url or path must be provided.")
+        super().__init__(url, path)
+
     @override
     async def read(self) -> bytes:
         return await super().read()
 
 
 class File(BaseFile):
-    def __init__(
-        self, url: str | None = None, path: str | None = None
-    ) -> None:
+    def __init__(self, url: str | None = None, path: str | None = None) -> None:
         self.file_name: str = ""
         if path:
             self.file_name = Path(path).name
